@@ -82,17 +82,16 @@ def _draw_animation(
         screen_color: str = "white", exit_on_click: bool = False,
         color: str = "black", width: Number = 1,
         frame_pause: Number = 0.1, screen: "turtle.Screen" = None,
-        screen_coords = (0, 0)
+        screen_coords = (0, 0), padding: Number = 100
     ) -> None:
     for shape in shapes_arr:
         if screen is not None:
             turtles.shape_turtle.clear()
-            # screen.setup(*screen_size)
-            # screen.bgcolor(screen_color)
         screen, turtles = shape.trace(
             screen = screen, screen_size = screen_size,
             screen_color = screen_color,
-            color = color, width=width, screen_coords=screen_coords
+            color = color, width=width, screen_coords=screen_coords,
+            padding=padding
         )
         time.sleep(frame_pause)
     if exit_on_click:
